@@ -163,7 +163,7 @@ class TestSimple(unittest.TestCase):
 
     def testReprioritizeNonExistentJob(self):
         """
-        Deleting a non-existent job must raise C{KeyError}.
+        Reprioritizing a non-existent job must raise C{KeyError}.
         """
         dq = ResizableDispatchQueue(None, 1)
         self.assertRaises(KeyError, dq.reprioritize, Job('x', 1), 10)
@@ -178,6 +178,17 @@ class TestSimple(unittest.TestCase):
         job = yield dq.put('a')
         self.assertRaises(RuntimeError, dq.reprioritize, job, 10)
 
+    def testReprioritizePending(self):
+        """
+        Reprioritize a pending job.
+        """
+        dq = ResizableDispatchQueue(None, 0)
+        dq.put('xxx', 5)
+        pending = dq.pending()
+        job = pending.pop()
+        dq.reprioritize(job, 10)
+        self.assertEqual(10, job.priority)
+
 
 class TestTiming(unittest.TestCase):
     """
@@ -209,7 +220,8 @@ class TestTiming(unittest.TestCase):
         self.assertFalse(dq.paused)
 
     def _testUnderway(self, dq, expected):
-        self.assertEqual(expected, dq.underway())
+        self.assertEqual(expected,
+                         set(job.jobarg for job in dq.underway()))
 
     def testJustOne(self):
         dq = ResizableDispatchQueue(self.slow, 1)
